<?php
/**
 * Smallbiz Theme Customizer
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function smallbiz_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector' => '.site-title a',
			'container_inclusive' => false,
			'render_callback' => 'smallbiz_customize_partial_blogname',
		) );
	}

	// Register new section: Theme Options
	$wp_customize->add_section( 'smallbiz_theme_options', array(
		'title'    => esc_html__( 'Smallbiz Options', 'smallbiz' ),
		'priority' => 130,
	) );

	// Register Container style setting
	$wp_customize->add_setting( 'smallbiz_container_style', array(
		'default'           => 'fullwidth',
		'sanitize_callback' => 'smallbiz_sanitize_container_style',
	) );
	$wp_customize->add_control( 'smallbiz_container_style', array(
		'label'             => esc_html__( 'Container style', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 1,
		'type'              => 'radio',
		'choices'           => array(
			'fullwidth' => esc_html__( 'Full Width', 'smallbiz' ),
			'boxed'     => esc_html__( 'Boxed', 'smallbiz' ),
			'framed'    => esc_html__( 'Framed', 'smallbiz' ),
		)
	) );

	// Register Custom RSS setting
	$wp_customize->add_setting( 'smallbiz_custom_rss', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control( 'smallbiz_custom_rss', array(
		'label'             => esc_html__( 'Custom RSS', 'smallbiz' ),
		'description'       => esc_html__( 'If you use 3rd party RSS service, place the URL here to change the default WordPress RSS URL.', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 3,
		'type'              => 'url'
	) );

	// Register Thumbnail Aspect Ratio setting
	$wp_customize->add_setting( 'smallbiz_thumbnail_style', array(
		'default'           => 'landscape',
		'sanitize_callback' => 'smallbiz_sanitize_thumbnail_style',
	) );
	$wp_customize->add_control( 'smallbiz_thumbnail_style', array(
		'label'             => esc_html__( 'Thumbnail Aspect Ratio', 'smallbiz' ),
		'description'       => esc_html__( 'Applied to front-page and grid page template.', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 5,
		'type'              => 'radio',
		'choices'           => array(
			'landscape' => esc_html__( 'Landscape (4:3)', 'smallbiz' ),
			'square'    => esc_html__( 'Square (1:1)', 'smallbiz' ),
		)
	) );

	// Register Page comment manager setting
	$wp_customize->add_setting( 'smallbiz_page_comment', array(
		'default'           => 1,
		'sanitize_callback' => 'smallbiz_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'smallbiz_page_comment', array(
		'label'             => esc_html__( 'Pages: Enable comment on Pages', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 7,
		'type'              => 'checkbox'
	) );

	// Register Page title setting
	$wp_customize->add_setting( 'smallbiz_page_title', array(
		'default'           => 1,
		'sanitize_callback' => 'smallbiz_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'smallbiz_page_title', array(
		'label'             => esc_html__( 'Pages: Show page title', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 9,
		'type'              => 'checkbox'
	) );

	// Register Page featured image setting
	$wp_customize->add_setting( 'smallbiz_page_featured_image', array(
		'default'           => 1,
		'sanitize_callback' => 'smallbiz_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'smallbiz_page_featured_image', array(
		'label'             => esc_html__( 'Pages: Show page featured image', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 11,
		'type'              => 'checkbox'
	) );

	// Register Post comment manager setting
	$wp_customize->add_setting( 'smallbiz_post_comment', array(
		'default'           => 1,
		'sanitize_callback' => 'smallbiz_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'smallbiz_post_comment', array(
		'label'             => esc_html__( 'Posts: Enable comment on Posts', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 13,
		'type'              => 'checkbox'
	) );

	// Register Author Box setting
	$wp_customize->add_setting( 'smallbiz_author_box', array(
		'default'           => 1,
		'sanitize_callback' => 'smallbiz_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'smallbiz_author_box', array(
		'label'             => esc_html__( 'Posts: Show author box', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 15,
		'type'              => 'checkbox'
	) );

	// Register Next & Prev post setting
	$wp_customize->add_setting( 'smallbiz_next_prev_post', array(
		'default'           => 1,
		'sanitize_callback' => 'smallbiz_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'smallbiz_next_prev_post', array(
		'label'             => esc_html__( 'Posts: Show next & prev post', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 17,
		'type'              => 'checkbox'
	) );

	// Register Footer Credits setting
	$default = '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed by <a href="https://www.theme-junkie.com/">Theme Junkie</a>';
	$wp_customize->add_setting( 'smallbiz_footer_credits', array(
		'default'           => $default,
		'sanitize_callback' => 'smallbiz_sanitize_textarea',
	) );
	$wp_customize->add_control( 'smallbiz_footer_credits', array(
		'label'             => esc_html__( 'Footer credits', 'smallbiz' ),
		'section'           => 'smallbiz_theme_options',
		'priority'          => 19,
		'type'              => 'textarea'
	) );

}
add_action( 'customize_register', 'smallbiz_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function smallbiz_customize_preview_js() {
	wp_enqueue_script( 'smallbiz-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'smallbiz_customize_preview_js' );

/**
 * Custom RSS feed url.
 */
function smallbiz_custom_rss_url( $output, $feed ) {

	// Get the custom rss feed url
	$url = get_theme_mod( 'smallbiz_custom_rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'smallbiz_custom_rss_url', 10, 2 );

/**
 * Display theme documentation on customizer page.
 */
function smallbiz_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'smallbiz-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'smallbiz-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.www.theme-junkie.com/smallbiz/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'smallbiz' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'smallbiz_documentation_link' );

/**
 * Render the site title for the selective refresh partial.
 *
 * Taken from Twenty Sixteen 1.2
 */
function smallbiz_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Sanitize the Container Style value.
 */
function smallbiz_sanitize_container_style( $style ) {
	if ( ! in_array( $style, array( 'fullwidth', 'boxed', 'framed' ) ) ) {
		$style = 'fullwidth';
	}
	return $style;
}

/**
 * Sanitize the Grid Thumbnail Aspect Ratio value.
 */
function smallbiz_sanitize_thumbnail_style( $ratio ) {
	if ( ! in_array( $ratio, array( 'landscape', 'square' ) ) ) {
		$ratio = 'landscape';
	}
	return $ratio;
}

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean (true|false).
 */
function smallbiz_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Footer Credits
 */
function smallbiz_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}
